==========
Attributes
==========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    DataFrame.columns
    DataFrame.dtypes
    DataFrame.flags
    DataFrame.height
    DataFrame.schema
    DataFrame.shape
    DataFrame.width
